@@ -678,7 +678,7 @@ def _CallAndUpdateTrace(component, args, component_trace, treatment='class',
 
   # Call the function.
   if inspectutils.IsCoroutineFunction(fn):
-    loop = asyncio.get_event_loop()
+    loop = asyncio.new_event_loop()
     component = loop.run_until_complete(fn(*varargs, **kwargs))
   else:
     component = fn(*varargs, **kwargs)
